@@ -1,3 +1,16 @@
+#########################################################################
+#             GNU HEALTH HOSPITAL MANAGEMENT - GTK CLIENT               #
+#                      https://www.gnuhealth.org                        #
+#########################################################################
+#       The GNUHealth HMIS client based on the Tryton GTK Client        #
+#########################################################################
+#
+# SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
+# SPDX-FileCopyrightText: 2017-2022 GNU Health Community <info@gnuhealth.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+
 # This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import gettext
@@ -201,7 +214,6 @@ class Date(Gtk.Entry):
                 assert isinstance(value, datetime.date), value
             self.__date = value
             self.update_label()
-            self.emit('date-changed')
         elif prop.name == 'format':
             self.__format = _fix_format(value)
             self.update_label()
@@ -374,7 +386,6 @@ class Time(Gtk.ComboBox):
                     value = value.time()
             self.__time = value
             self.update_label()
-            self.emit('time-changed')
         elif prop.name == 'format':
             self.__format = _fix_format(value)
             self.update_label()
