@@ -1,10 +1,23 @@
+#########################################################################
+#             GNU HEALTH HOSPITAL MANAGEMENT - GTK CLIENT               #
+#                      https://www.gnuhealth.org                        #
+#########################################################################
+#       The GNUHealth HMIS client based on the Tryton GTK Client        #
+#########################################################################
+#
+# SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
+# SPDX-FileCopyrightText: 2017-2022 GNU Health Community <info@gnuhealth.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+
 # This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-import os
-import gettext
-from gi.repository import Gtk, GdkPixbuf
 
-from gnuhealth.config import PIXMAPS_DIR, CONFIG, GH_ABOUT
+import gettext
+from gi.repository import Gtk
+
+from gnuhealth.config import CONFIG, GH_ABOUT
 from gnuhealth.common import get_toplevel_window
 from gnuhealth import __version__
 
