@@ -1,3 +1,16 @@
+#########################################################################
+#             GNU HEALTH HOSPITAL MANAGEMENT - GTK CLIENT               #
+#                      https://www.gnuhealth.org                        #
+#########################################################################
+#       The GNUHealth HMIS client based on the Tryton GTK Client        #
+#########################################################################
+#
+# SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
+# SPDX-FileCopyrightText: 2017-2022 GNU Health Community <info@gnuhealth.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+
 # This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import sys
@@ -475,10 +488,7 @@ class ViewTree(View):
         self.treeview.connect('key-press-event', self.on_keypress)
         self.treeview.connect_after('row-activated', self.__sig_switch)
         if self.children_field:
-            child_col = 1 if self.draggable else 0
             self.treeview.connect('test-expand-row', self.test_expand_row)
-            self.treeview.set_expander_column(
-                self.treeview.get_column(child_col))
         self.treeview.set_rubber_banding(True)
 
         selection = self.treeview.get_selection()
@@ -1083,6 +1093,13 @@ class ViewTree(View):
                     inv_domain = simplify(inv_domain)
                 unique, _, _ = unique_value(inv_domain)
                 column.set_visible(not unique or bool(self.children_field))
+        if self.children_field:
+            for i, column in enumerate(self.treeview.get_columns()):
+                if self.draggable and not i:
+                    continue
+                if column.get_visible():
+                    self.treeview.set_expander_column(column)
+                    break
 
     def set_state(self):
         record = self.record
@@ -1147,7 +1164,7 @@ class ViewTree(View):
     def set_cursor(self, new=False, reset_view=True):
         self.treeview.grab_focus()
         model = self.treeview.get_model()
-        if self.record and model:
+        if self.record and model and self.treeview.get_realized():
             path = self.record.get_index_path(model.group)
             if model.get_flags() & Gtk.TreeModelFlags.LIST_ONLY:
                 path = (path[0],)
