@@ -1,3 +1,16 @@
+#########################################################################
+#             GNU HEALTH HOSPITAL MANAGEMENT - GTK CLIENT               #
+#                      https://www.gnuhealth.org                        #
+#########################################################################
+#       The GNUHealth HMIS client based on the Tryton GTK Client        #
+#########################################################################
+#
+# SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
+# SPDX-FileCopyrightText: 2017-2022 GNU Health Community <info@gnuhealth.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+
 # This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import datetime
@@ -5,6 +18,7 @@ import os
 import gettext
 import webbrowser
 from functools import wraps, partial
+from weakref import WeakKeyDictionary
 
 from gi.repository import Gdk, GLib, Gtk
 
@@ -51,16 +65,24 @@ def send_keys(renderer, editable, position, treeview):
 
 
 def realized(func):
-    "Decorator for treeview realized"
+
     @wraps(func)
     def wrapper(self, *args, **kwargs):
-        if (hasattr(self.view.treeview, 'get_realized')
-                and not self.view.treeview.get_realized()):
-            return
+        has_been_realized = _REALIZED.get(self.view.treeview, False)
+        if not has_been_realized:
+            has_been_realized = self.view.treeview.get_realized()
+            if has_been_realized:
+                self.view.treeview.queue_resize()
+                _REALIZED[self.view.treeview] = True
+            else:
+                return
         return func(self, *args, **kwargs)
     return wrapper
 
 
+_REALIZED = WeakKeyDictionary()
+
+
 class CellCache(list):
 
     methods = ('set_active', 'set_sensitive', 'set_property')
@@ -1287,17 +1309,24 @@ class Button(Cell):
         # TODO icon
         self._set_visual(cell, record)
 
+    @common.idle_add
     def button_clicked(self, widget, path):
         if not path:
             return True
         store = self.view.treeview.get_model()
         record = store.get_value(store.get_iter(path), 0)
 
+        if self.view.record and self.view.record != record:
+            widget.stop_emission_by_name('clicked')
+            return True
+
         state_changes = record.expr_eval(
             self.attrs.get('states', {}))
         if state_changes.get('invisible') \
                 or state_changes.get('readonly'):
             return True
+
+        self.view.treeview.set_cursor(path)
         widget.handler_block_by_func(self.button_clicked)
         try:
             self.view.screen.button(self.attrs)
