@@ -1,3 +1,16 @@
+#########################################################################
+#             GNU HEALTH HOSPITAL MANAGEMENT - GTK CLIENT               #
+#                      https://www.gnuhealth.org                        #
+#########################################################################
+#       The GNUHealth HMIS client based on the Tryton GTK Client        #
+#########################################################################
+#
+# SPDX-FileCopyrightText: 2008-2021 The Tryton Community <info@tryton.org>
+# SPDX-FileCopyrightText: 2017-2022 GNU Health Community <info@gnuhealth.org>
+#
+# SPDX-License-Identifier: GPL-3.0-or-later
+
+
 # This file is part of GNU Health.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 import json
@@ -153,7 +166,7 @@ class Eval(PYSON):
 
     @staticmethod
     def eval(dct, context):
-        if '.' in dct['v']:
+        if '.' in dct['v'] and dct['v'] not in context:
             base, name = dct['v'].split('.', 1)
             return Eval.eval({
                     'v': name,
@@ -509,7 +522,10 @@ class In(PYSON):
 
     @staticmethod
     def eval(dct, context):
-        return dct['k'] in dct['v']
+        if dct['v']:
+            return dct['k'] in dct['v']
+        else:
+            return False
 
 
 class Date(PYSON):
